Crate sp1_recursion_executor

Crate sp1_recursion_executor 

Re-exports

pub use analyzed::AnalyzedInstruction;
pub use instruction::Instruction;

Modules

analyzed
basic_block
instruction
raw
seq_block
shape

Structs

Address
BaseAluInstr
An instruction invoking the extension field ALU.
BaseAluIo
The inputs and outputs to an operation of the base field ALU.
BasicBlock
Block
The smallest unit of memory that can be read and written to.
CommitPublicValuesEvent
The event for committing to the public values.
CommitPublicValuesInstr
An instruction that will save the public values to the execution record and will commit to it’s digest.
ExecutionRecord
Executor
TODO fully document. Taken from [sp1_recursion_executor::executor::Runtime]. Many missing things (compared to the old Runtime) will need to be implemented.
ExtAluInstr
An instruction invoking the extension field ALU.
ExtAluIo
The inputs and outputs to an operation of the extension field ALU.
ExtFeltEvent
An event recording an ext2felt or felt2ext operation.
ExtFeltInstr
An instruction invoking the ext2felt or felt2ext operation. This 5 is derived from D + 1. The first address is the extension, and the rest are felts.
MemInstr
MemIo
The inputs and outputs to the manual memory management/memory initialization table.
Poseidon2Instr
An instruction invoking the Poseidon2 permutation.
Poseidon2Io
The inputs and outputs to a Poseidon2 permutation.
Poseidon2LinearLayerInstr
An instruction invoking the Poseidon2 permutation linear layers.
Poseidon2LinearLayerIo
The inputs and outputs to a Poseidon2 permutation linear layers. The 4 here is calculated from PERMUTATION_WIDTH / D.
Poseidon2SBoxInstr
An instruction invoking the SBOX operation.
Poseidon2SBoxIo
The inputs and outputs to an SBOX operation.
PrefixSumChecksEvent
The event encoding the inputs and outputs of an PrefixSumChecks operation.
PrefixSumChecksInstr
An instruction invoking the PrefixSumChecks operation.
PrefixSumChecksIo
The inputs and outputs to the operations for prefix sum checks.
RawProgram
RecursionAirEventCount
RecursionProgram
A well-formed recursion program. See Self::new_unchecked for guaranteed (safety) invariants.
RecursionPublicValues
The PublicValues struct is used to store all of a recursion proof’s public values.
RootProgram
SelectInstr
An instruction invoking the select operation.
SelectIo
The inputs and outputs to a select operation.
UnsafeRecord

Enums

BaseAluOpcode
ExtAluOpcode
MemAccessKind
RuntimeError
SeqBlock
Segments that may be sequentially composed.

Constants

D
DIGEST_SIZE
The current verifier implementation assumes that we are using a 256-bit hash with 32-bit elements.
HASH_RATE
NUM_BITS
NUM_PV_ELMS_TO_HASH
PERMUTATION_WIDTH
The width of the Poseidon2 permutation.
POSEIDON2_SBOX_DEGREE
PV_DIGEST_NUM_WORDS
RECURSIVE_PROOF_NUM_PV_ELTS

Type Aliases

BaseAluEvent
ExtAluEvent
MemEvent
Poseidon2Event
Poseidon2LinearLayerEvent
Poseidon2SBoxEvent
SelectEvent
The event encoding the inputs and outputs of a select operation.