pub struct RawProgram<T> {
pub seq_blocks: Vec<SeqBlock<T>>,
}Fields
seq_blocks: Vec<SeqBlock<T>>Implementations
Sourceimpl<F> RawProgram<Instruction<F>>
impl<F> RawProgram<Instruction<F>>
Sourcepub fn analyze(
self,
) -> (RawProgram<AnalyzedInstruction<F>>, RecursionAirEventCount)
pub fn analyze( self, ) -> (RawProgram<AnalyzedInstruction<F>>, RecursionAirEventCount)
Analyze the program to link an instruction to its corresponding event count.
This allows the executor to preallocate the correct number of events and avoid copies across blocks.
This method is not unsafe, but the correctness of this method is a safety condition of
[crate::Runtime::execute_raw].