RecursionPublicValues

Struct RecursionPublicValues 

#[repr(C)]
pub struct RecursionPublicValues<T> {
Show 34 fields pub prev_committed_value_digest: [[T; 4]; 8], pub committed_value_digest: [[T; 4]; 8], pub prev_deferred_proofs_digest: [T; 8], pub deferred_proofs_digest: [T; 8], pub prev_deferred_proof: T, pub deferred_proof: T, pub pc_start: [T; 3], pub next_pc: [T; 3], pub initial_timestamp: [T; 4], pub last_timestamp: [T; 4], pub previous_init_addr: [T; 3], pub last_init_addr: [T; 3], pub previous_finalize_addr: [T; 3], pub last_finalize_addr: [T; 3], pub previous_init_page_idx: [T; 3], pub last_init_page_idx: [T; 3], pub previous_finalize_page_idx: [T; 3], pub last_finalize_page_idx: [T; 3], pub start_reconstruct_deferred_digest: [T; 8], pub end_reconstruct_deferred_digest: [T; 8], pub sp1_vk_digest: [T; 8], pub vk_root: [T; 8], pub global_cumulative_sum: SepticDigest<T>, pub contains_first_shard: T, pub num_included_shard: T, pub is_complete: T, pub prev_exit_code: T, pub exit_code: T, pub prev_commit_syscall: T, pub commit_syscall: T, pub prev_commit_deferred_syscall: T, pub commit_deferred_syscall: T, pub digest: [T; 8], pub proof_nonce: [T; 4],
}
The PublicValues struct is used to store all of a recursion proof’s public values.

Fields

prev_committed_value_digest: [[T; 4]; 8]

The committed_value_digest before this shard.

committed_value_digest: [[T; 4]; 8]

The hash of all the bytes that the program has written to public values.

prev_deferred_proofs_digest: [T; 8]

The deferred_proofs_digest before this shard.

deferred_proofs_digest: [T; 8]

The hash of all deferred proofs that have been witnessed in the VM.

prev_deferred_proof: T

The deferred proof index before this shard.

deferred_proof: T

The deferred proof index after this shard.

pc_start: [T; 3]

The start pc of shards being proven.

next_pc: [T; 3]

The expected start pc for the next shard.

initial_timestamp: [T; 4]

The initial timestamp.

last_timestamp: [T; 4]

The last timestamp.

previous_init_addr: [T; 3]

Previous MemoryInit address.

last_init_addr: [T; 3]

Last MemoryInit address.

previous_finalize_addr: [T; 3]

Previous MemoryFinalize address.

last_finalize_addr: [T; 3]

Last MemoryFinalize address.

previous_init_page_idx: [T; 3]

Previous PageProtInit page index.

last_init_page_idx: [T; 3]

Last PageProtInit page index.

previous_finalize_page_idx: [T; 3]

Previous PageProtFinalize page index.

last_finalize_page_idx: [T; 3]

Last PageProtFinalize page index.

start_reconstruct_deferred_digest: [T; 8]

Start state of reconstruct_deferred_digest.

end_reconstruct_deferred_digest: [T; 8]

End state of reconstruct_deferred_digest.

sp1_vk_digest: [T; 8]

The commitment to the sp1 program being proven.

vk_root: [T; 8]

The root of the vk merkle tree.

global_cumulative_sum: SepticDigest<T>

Current cumulative sum of lookup bus. Note that for recursive proofs for core proofs, this contains the global cumulative sum.

contains_first_shard: T

Whether or not the first shard is inside the compress proof.

num_included_shard: T

The total number of included core shards inside the compress proof.

is_complete: T

Whether the proof completely proves the program execution.

prev_exit_code: T

The expected exit code of the program before this shard.

exit_code: T

The expected exit code of the program up to this shard.

prev_commit_syscall: T

The commit_syscall value of the previous shard.

commit_syscall: T

Whether COMMIT syscall has been called up to this shard.

prev_commit_deferred_syscall: T

The commit_deferred_syscall value of the previous shard.

commit_deferred_syscall: T

Whether COMMIT_DEFERRED syscall has been called up to this shard.

digest: [T; 8]

The digest of all the previous public values elements.

proof_nonce: [T; 4]

The nonce used for this proof.

Implementations

Source

impl<F: Copy> RecursionPublicValues<F>

Converts the public values to an array of elements.

pub fn as_array(&self) -> [F; 187]

pub fn range(&self) -> ShardRange
where F: PrimeField32,