Re-exports
pub use analyzed::AnalyzedInstruction;pub use instruction::Instruction;
Modules
Structs
- Address
- Base
AluInstr - An instruction invoking the extension field ALU.
- Base
AluIo - The inputs and outputs to an operation of the base field ALU.
- Basic
Block - Block
- The smallest unit of memory that can be read and written to.
- Commit
Public Values Event - The event for committing to the public values.
- Commit
Public Values Instr - An instruction that will save the public values to the execution record and will commit to it’s digest.
- Execution
Record - Executor
- TODO fully document.
Taken from [
sp1_recursion_executor::executor::Runtime]. Many missing things (compared to the oldRuntime) will need to be implemented. - ExtAlu
Instr - An instruction invoking the extension field ALU.
- ExtAlu
Io - The inputs and outputs to an operation of the extension field ALU.
- ExtFelt
Event - An event recording an ext2felt or felt2ext operation.
- ExtFelt
Instr - An instruction invoking the ext2felt or felt2ext operation.
This
5is derived fromD + 1. The first address is the extension, and the rest are felts. - MemInstr
- MemIo
- The inputs and outputs to the manual memory management/memory initialization table.
- Poseidon2
Instr - An instruction invoking the Poseidon2 permutation.
- Poseidon2
Io - The inputs and outputs to a Poseidon2 permutation.
- Poseidon2
Linear Layer Instr - An instruction invoking the Poseidon2 permutation linear layers.
- Poseidon2
Linear Layer Io - The inputs and outputs to a Poseidon2 permutation linear layers.
The
4here is calculated fromPERMUTATION_WIDTH / D. - Poseidon2S
BoxInstr - An instruction invoking the SBOX operation.
- Poseidon2S
BoxIo - The inputs and outputs to an SBOX operation.
- Prefix
SumChecks Event - The event encoding the inputs and outputs of an PrefixSumChecks operation.
- Prefix
SumChecks Instr - An instruction invoking the PrefixSumChecks operation.
- Prefix
SumChecks Io - The inputs and outputs to the operations for prefix sum checks.
- RawProgram
- Recursion
AirEvent Count - Recursion
Program - A well-formed recursion program. See
Self::new_uncheckedfor guaranteed (safety) invariants. - Recursion
Public Values - The PublicValues struct is used to store all of a recursion proof’s public values.
- Root
Program - Select
Instr - An instruction invoking the select operation.
- Select
Io - The inputs and outputs to a select operation.
- Unsafe
Record
Enums
- Base
AluOpcode - ExtAlu
Opcode - MemAccess
Kind - Runtime
Error - SeqBlock
- Segments that may be sequentially composed.
Constants
- D
- DIGEST_
SIZE - The current verifier implementation assumes that we are using a 256-bit hash with 32-bit elements.
- HASH_
RATE - NUM_
BITS - NUM_
PV_ ELMS_ TO_ HASH - PERMUTATION_
WIDTH - The width of the Poseidon2 permutation.
- POSEIDO
N2_ SBOX_ DEGREE - PV_
DIGEST_ NUM_ WORDS - RECURSIVE_
PROOF_ NUM_ PV_ ELTS
Type Aliases
- Base
AluEvent - ExtAlu
Event - MemEvent
- Poseidon2
Event - Poseidon2
Linear Layer Event - Poseidon2S
BoxEvent - Select
Event - The event encoding the inputs and outputs of a select operation.